@@ -2,6 +2,19 @@ package libgobuster
 
 import "sync"
 
+type MessageLevel int
+
+const (
+	LevelDebug MessageLevel = iota
+	LevelInfo
+	LevelError
+)
+
+type Message struct {
+	Level   MessageLevel
+	Message string
+}
+
 type Progress struct {
 	requestsExpectedMutex *sync.RWMutex
 	requestsExpected      int
@@ -9,6 +22,7 @@ type Progress struct {
 	requestsIssued        int
 	ResultChan            chan Result
 	ErrorChan             chan error
+	MessageChan           chan Message
 }
 
 func NewProgress() *Progress {
@@ -18,6 +32,7 @@ func NewProgress() *Progress {
 	p.requestsCountMutex = new(sync.RWMutex)
 	p.ResultChan = make(chan Result)
 	p.ErrorChan = make(chan error)
+	p.MessageChan = make(chan Message)
 	return &p
 }
 
@@ -33,6 +48,12 @@ func (p *Progress) RequestsIssued() int {
 	return p.requestsIssued
 }
 
+func (p *Progress) incrementRequestsIssues(by int) {
+	p.requestsCountMutex.Lock()
+	defer p.requestsCountMutex.Unlock()
+	p.requestsIssued += by
+}
+
 func (p *Progress) incrementRequests() {
 	p.requestsCountMutex.Lock()
 	defer p.requestsCountMutex.Unlock()
